@@ -20,13 +20,16 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdarg.h>
+#include <locale.h>
 
 #include "unittest.h"
 #include "mp-equation.h"
+#include "mp-serializer.h"
 
 static MPEquationOptions options;
 
 static int fails = 0;
+static int passes = 0;
 
 /* If we're not using GNU C, elide __attribute__ */
 #ifndef __GNUC__
@@ -36,15 +39,18 @@ static int fails = 0;
 static void pass(const char *format, ...) __attribute__((format(printf, 1, 2)));
 static void fail(const char *format, ...) __attribute__((format(printf, 1, 2)));
 
+
 static void pass(const char *format, ...)
 {
-    va_list args;
+/*    va_list args;
 
     printf(" PASS: ");
     va_start(args, format);
     vprintf(format, args);
     va_end(args);
     printf("\n");
+*/
+    passes += 1;
 }
 
 static void fail(const char *format, ...)
@@ -78,22 +84,31 @@ test(char *expression, char *expected, int expected_error)
 {
     MPErrorCode error;
     MPNumber result;
-    char result_str[1024] = "";
 
     error = mp_equation_parse(expression, &options, &result, NULL);
 
     if(error == 0) {
-        mp_cast_to_string(&result, options.base, options.base, 9, 1, result_str, 1024);
-        if(expected_error != 0)
+        char *result_str;
+        MpSerializer *serializer;
+
+        serializer = mp_serializer_new(MP_DISPLAY_FORMAT_FIXED, options.base, 9);
+        result_str = mp_serializer_to_string(serializer, &result);
+        g_object_unref(serializer);
+
+        if(expected_error != PARSER_ERR_NONE)
             fail("'%s' -> %s, expected error %s", expression, result_str, error_code_to_string(expected_error));
         else if(strcmp(result_str, expected) != 0)
             fail("'%s' -> '%s', expected '%s'", expression, result_str, expected);
         else
             pass("'%s' -> '%s'", expression, result_str);
+        g_free(result_str);
     }
     else {
         if(error == expected_error)
             pass("'%s' -> error %s", expression, error_code_to_string(error));
+        else if(expected_error == PARSER_ERR_NONE)
+            fail("'%s' -> error %s, expected result %s", expression,
+                 error_code_to_string(error), expected);
         else
             fail("'%s' -> error %s, expected error %s", expression,
                  error_code_to_string(error), error_code_to_string(expected_error));
@@ -752,10 +767,13 @@ test_mp()
 
 void
 unittest()
-{    
+{
+    setlocale(LC_ALL, "C");
     test_mp();
     test_numbers();
     test_conversions();
     test_equations();
+    if (fails == 0)
+        printf("Passed all %i tests\n", passes);
     exit(fails > 0 ? 1 : 0);
 }
